@@ -7,10 +7,9 @@ use std::sync::atomic::{AtomicBool, AtomicUsize, Ordering};
 use std::sync::Arc;
 use std::{thread, time};
 
-use crate::goose::GooseRequest;
 use crate::metrics::{
-    self, GooseErrorMetric, GooseErrorMetrics, GooseRequestMetrics, GooseTaskMetric,
-    GooseTaskMetrics,
+    self, GooseErrorMetricAggregate, GooseErrorMetrics, GooseRequestMetricAggregate,
+    GooseRequestMetrics, GooseTaskMetricAggregate, GooseTaskMetrics,
 };
 use crate::util;
 use crate::worker::GaggleMetrics;
@@ -76,9 +75,9 @@ fn pipe_closed(_pipe: Pipe, event: PipeEvent) {
 
 /// Merge per-user task metrics from user thread into global parent metrics
 fn merge_tasks_from_worker(
-    parent_task: &GooseTaskMetric,
-    user_task: &GooseTaskMetric,
-) -> GooseTaskMetric {
+    parent_task: &GooseTaskMetricAggregate,
+    user_task: &GooseTaskMetricAggregate,
+) -> GooseTaskMetricAggregate {
     // Make a mutable copy where we can merge things
     let mut merged_task = parent_task.clone();
     // Iterate over user times, and merge into global time
@@ -100,30 +99,30 @@ fn merge_tasks_from_worker(
 
 /// Merge per-user request metrics from user thread into global parent metrics
 fn merge_requests_from_worker(
-    parent_request: &GooseRequest,
-    user_request: &GooseRequest,
+    parent_request: &GooseRequestMetricAggregate,
+    user_request: &GooseRequestMetricAggregate,
     status_codes: bool,
-) -> GooseRequest {
+) -> GooseRequestMetricAggregate {
     // Make a mutable copy where we can merge things
     let mut merged_request = parent_request.clone();
     // Iterate over user response times, and merge into global response time
-    merged_request.response_times = metrics::merge_times(
-        merged_request.response_times,
-        user_request.response_times.clone(),
+    merged_request.raw_data.times = metrics::merge_times(
+        merged_request.raw_data.times,
+        user_request.raw_data.times.clone(),
     );
     // Increment total response time counter.
-    merged_request.total_response_time += &user_request.total_response_time;
+    merged_request.raw_data.total_time += &user_request.raw_data.total_time;
     // Increment count of how many response counters we've seen.
-    merged_request.response_time_counter += &user_request.response_time_counter;
+    merged_request.raw_data.counter += &user_request.raw_data.counter;
     // If user had new fastest response time, update global fastest response time.
-    merged_request.min_response_time = metrics::update_min_time(
-        merged_request.min_response_time,
-        user_request.min_response_time,
+    merged_request.raw_data.minimum_time = metrics::update_min_time(
+        merged_request.raw_data.minimum_time,
+        user_request.raw_data.minimum_time,
     );
     // If user had new slowest response time, update global slowest response time.
-    merged_request.max_response_time = metrics::update_max_time(
-        merged_request.max_response_time,
-        user_request.max_response_time,
+    merged_request.raw_data.maximum_time = metrics::update_max_time(
+        merged_request.raw_data.maximum_time,
+        user_request.raw_data.maximum_time,
     );
     // Increment total success counter.
     merged_request.success_count += &user_request.success_count;
@@ -153,9 +152,9 @@ fn merge_requests_from_worker(
 
 /// Merge per-Worker errors into global Manager metrics
 fn merge_errors_from_worker(
-    manager_error: &GooseErrorMetric,
-    worker_error: &GooseErrorMetric,
-) -> GooseErrorMetric {
+    manager_error: &GooseErrorMetricAggregate,
+    worker_error: &GooseErrorMetricAggregate,
+) -> GooseErrorMetricAggregate {
     // Make a mutable copy where we can merge things
     let mut merged_error = manager_error.clone();
     // Add in how many additional times this happened on the Worker.
@@ -252,7 +251,7 @@ fn merge_error_metrics(goose_attack: &mut GooseAttack, errors: GooseErrorMetrics
 }
 
 /// Main manager loop.
-pub async fn manager_main(mut goose_attack: GooseAttack) -> GooseAttack {
+pub(crate) async fn manager_main(mut goose_attack: GooseAttack) -> GooseAttack {
     // Creates a TCP address.
     let address = format!(
         "tcp://{}:{}",
