@@ -10,7 +10,7 @@
 pub use crate::goose::{
     GooseTask, GooseTaskError, GooseTaskFunction, GooseTaskResult, GooseTaskSet, GooseUser,
 };
-pub use crate::metrics::GooseMetrics;
+pub use crate::metrics::{GooseCoordinatedOmissionMitigation, GooseMetrics};
 pub use crate::{
     task, taskset, GooseAttack, GooseDefault, GooseDefaultType, GooseError, GooseScheduler,
 };
