@@ -4,9 +4,10 @@ use std::time;
 
 use crate::get_worker_id;
 use crate::goose::{GooseTaskFunction, GooseTaskSet, GooseUser, GooseUserCommand};
-use crate::metrics::{GooseMetric, GooseRawTask};
+use crate::logger::GooseLog;
+use crate::metrics::{GooseMetric, GooseTaskMetric};
 
-pub async fn user_main(
+pub(crate) async fn user_main(
     thread_number: usize,
     thread_task_set: GooseTaskSet,
     thread_user: GooseUser,
@@ -38,8 +39,9 @@ pub async fn user_main(
                 thread_number, thread_task_name, thread_task_set.name
             );
             // Invoke the task function.
-            invoke_task_function(function, &thread_user, *thread_task_index, thread_task_name)
-                .await;
+            let _todo =
+                invoke_task_function(function, &thread_user, *thread_task_index, thread_task_name)
+                    .await;
         }
     }
 
@@ -50,6 +52,11 @@ pub async fn user_main(
             // Start at the first task in thread_user.weighted_tasks.
             position = 0;
             thread_user.position.store(position, Ordering::SeqCst);
+
+            // Tracks the time it takes to loop through all GooseTasks when Coordinated Omission
+            // Mitigation is enabled.
+            thread_user.update_request_cadence(thread_number).await;
+
             for (thread_task_index, thread_task_name) in &thread_user.weighted_tasks {
                 // Determine which task we're going to run next.
                 let function = &thread_task_set.tasks[*thread_task_index].function;
@@ -58,8 +65,13 @@ pub async fn user_main(
                     thread_task_name, thread_task_set.name
                 );
                 // Invoke the task function.
-                invoke_task_function(function, &thread_user, *thread_task_index, thread_task_name)
-                    .await;
+                let _todo = invoke_task_function(
+                    function,
+                    &thread_user,
+                    *thread_task_index,
+                    thread_task_name,
+                )
+                .await;
 
                 // Prepare to sleep for a random value from min_wait to max_wait.
                 let wait_time = if thread_user.max_wait > 0 {
@@ -73,6 +85,8 @@ pub async fn user_main(
 
                 // Wake every second to check if the parent thread has told us to exit.
                 let mut in_sleep_loop = true;
+                // Track the time slept for Coordinated Omission Mitigation.
+                let sleep_timer = time::Instant::now();
                 while in_sleep_loop {
                     let mut message = thread_receiver.try_recv();
                     while message.is_ok() {
@@ -102,6 +116,12 @@ pub async fn user_main(
                         in_sleep_loop = false;
                     }
                 }
+                // Track how much time the GooseUser sleeps during this loop through all GooseTasks,
+                // used by Coordinated Omission Mitigation.
+                thread_user.slept.fetch_add(
+                    (time::Instant::now() - sleep_timer).as_millis() as u64,
+                    Ordering::SeqCst,
+                );
 
                 // Move to the next task in thread_user.weighted_tasks.
                 position += 1;
@@ -121,8 +141,9 @@ pub async fn user_main(
                 thread_number, thread_task_name, thread_task_set.name
             );
             // Invoke the task function.
-            invoke_task_function(function, &thread_user, *thread_task_index, thread_task_name)
-                .await;
+            let _todo =
+                invoke_task_function(function, &thread_user, *thread_task_index, thread_task_name)
+                    .await;
         }
     }
 
@@ -148,9 +169,9 @@ async fn invoke_task_function(
     thread_user: &GooseUser,
     thread_task_index: usize,
     thread_task_name: &str,
-) {
+) -> Result<(), flume::SendError<Option<GooseLog>>> {
     let started = time::Instant::now();
-    let mut raw_task = GooseRawTask::new(
+    let mut raw_task = GooseTaskMetric::new(
         thread_user.started.elapsed().as_millis(),
         thread_user.task_sets_index,
         thread_task_index,
@@ -162,7 +183,14 @@ async fn invoke_task_function(
 
     // Exit if all metrics or task metrics are disabled.
     if thread_user.config.no_metrics || thread_user.config.no_task_metrics {
-        return;
+        return Ok(());
+    }
+
+    // If tasks-file is enabled, send a copy of the raw task metric to the logger thread.
+    if !thread_user.config.task_log.is_empty() {
+        if let Some(logger) = thread_user.logger.as_ref() {
+            logger.send(Some(GooseLog::Task(raw_task.clone())))?;
+        }
     }
 
     // Otherwise send metrics to parent.
@@ -170,4 +198,6 @@ async fn invoke_task_function(
         // Best effort metrics.
         let _ = parent.send(GooseMetric::Task(raw_task));
     }
+
+    Ok(())
 }
